/****************************************************************************
** Form interface generated from reading ui file '/home/arnaud/Works/Corporation/Gaia/Games/New/kmastermind/src/leveldlg.ui'
**
** Created: ven sep 2 17:56:02 2005
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef LEVELDLG_H
#define LEVELDLG_H

#include <qvariant.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QButtonGroup;
class QRadioButton;
class QPushButton;

class LevelDlg : public QDialog
{
    Q_OBJECT

public:
    LevelDlg( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~LevelDlg();

    QButtonGroup* levelGroup;
    QRadioButton* radioNovice;
    QRadioButton* radioMedium;
    QRadioButton* radioExpert;
    QPushButton* buttonOk;
    QPushButton* buttonCancel;

protected:
    QVBoxLayout* LevelDlgLayout;
    QVBoxLayout* levelGroupLayout;
    QHBoxLayout* Layout1;
    QSpacerItem* Horizontal_Spacing2;

protected slots:
    virtual void languageChange();

};

#endif // LEVELDLG_H
