/***************************************************************************
 *   Copyright (C) 2005 by Tavarez Arnaud Bakoula                          *
 *   tbakoula@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef TICK_MANAGER_H
#define TICK_MANAGER_H

#include "cellmanager.h"

class Tick;
class TickRow;

class TickManager : public CellManager
{
public:
    TickManager( uint r, uint c, QWidget* parent=0, const char* name=0 );
    virtual ~TickManager();

    virtual void createRows();
    virtual void appendCellRow( uint ap );
    virtual bool installActiveRow( CellRow* );
    virtual bool installActiveRow( uint black, uint white, bool hard=false );

protected:
    virtual void paintCell( Cell* cell, QPainter* p=0 );

    virtual void mouseMoveEvent( QMouseEvent* );
    virtual void mousePressEvent( QMouseEvent* );
    virtual void mouseReleaseEvent( QMouseEvent* );

    virtual void dropEvent( QDropEvent* );
    virtual void dragEnterEvent( QDragEnterEvent* );

    virtual void drawReady( Cell* );

protected:
    Tick* activeCell;

private:
    TickManager( const TickManager& );
    TickManager& operator=( const TickManager& );
};

#endif // TICK_MANAGER_H
