/****************************************************************************
** Form interface generated from reading ui file '/home/arnaud/Works/Corporation/Gaia/Games/New/kmastermind/src/modedlg.ui'
**
** Created: ven sep 2 17:56:05 2005
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef MODEDLG_H
#define MODEDLG_H

#include <qvariant.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QButtonGroup;
class QRadioButton;
class QPushButton;

class ModeDlg : public QDialog
{
    Q_OBJECT

public:
    ModeDlg( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~ModeDlg();

    QButtonGroup* modeGroup;
    QRadioButton* radioStandard;
    QRadioButton* radioMachine;
    QRadioButton* radioHuman;
    QPushButton* buttonOk;
    QPushButton* buttonCancel;

protected:
    QVBoxLayout* ModeDlgLayout;
    QVBoxLayout* modeGroupLayout;
    QHBoxLayout* Layout1;
    QSpacerItem* Horizontal_Spacing2;

protected slots:
    virtual void languageChange();

};

#endif // MODEDLG_H
