/***************************************************************************
 *   Copyright (C) 2005 by Tavarez Arnaud Bakoula                          *
 *   tbakoula@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef NOTIFICATION_H
#define NOTIFICATION_H

#include <cassert>
#include <vector>

#include "mark.h"

/**
@author Tavarez Arnaud Bakoula
*/
class Notification
{
private:
    uint dim;
    std::vector<Mark> *pMarksList;

public:
    Notification();
    Notification( uint nb );
    Notification( const Notification& cmb );
    ~Notification();

    uint getDim() const {  return dim;  }

    Notification& operator=( const Notification& cmb );

    Mark& operator []( uint n )
    {
      assert( n < dim );
      return pMarksList->operator[]( n );
    }

    const Mark& operator []( uint n ) const
    {
      assert( n < dim );
      return pMarksList->operator[]( n );
    }

    void addMarks( uint nb );
    void removeMarks( uint nb );
    void reset();

    void doCount();
    void resetCount();

    int* count;   /*!< This array stores the number of occurences of
                       a particular color */
};

#endif  // NOTIFICATION_H
