<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kmastermind" version="2.2">
<MenuBar>
  <Menu name="file"><text>F&amp;ile</text>
    <Action name="new" />
    <Action name="score" />
    <Separator/>
    <Action name="exit" />
  </Menu>
  <Menu name="settings"><text>S&amp;ettings</text>
    <Action name="datacfg" />
    <Action name="modecfg" />
    <Action name="levelcfg" />
    <Separator/>
    <Action name="appearancecfg" />
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar">
  <Action name="new" />
  <Action name="submit" />
  <Action name="record" />
  <Action name="suggest" />
  <Separator/>
  <Action name="exit" />
</ToolBar>
</kpartgui>
