/****************************************************************************
** Form interface generated from reading ui file '/home/arnaud/Works/Corporation/Gaia/Games/New/kmastermind/src/datadlg.ui'
**
** Created: mar sep 27 23:15:49 2005
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef DATADLG_H
#define DATADLG_H

#include <qvariant.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QGroupBox;
class QSpinBox;
class QLabel;
class QPushButton;

class DataDlg : public QDialog
{
    Q_OBJECT

public:
    DataDlg( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~DataDlg();

    QGroupBox* dataGroup;
    QSpinBox* spinTries;
    QSpinBox* spinPions;
    QSpinBox* spinColors;
    QLabel* textLabel6;
    QLabel* textLabel5;
    QLabel* textLabel7;
    QPushButton* buttonOk;
    QPushButton* buttonCancel;

protected:
    QVBoxLayout* DataDlgLayout;
    QGridLayout* dataGroupLayout;
    QHBoxLayout* Layout1;
    QSpacerItem* Horizontal_Spacing2;

protected slots:
    virtual void languageChange();

};

#endif // DATADLG_H
