/****************************************************************************
** Form interface generated from reading ui file '/home/arnaud/Works/Corporation/Gaia/Games/New/kmastermind/src/appearancedlg.ui'
**
** Created: ven sep 2 17:55:57 2005
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef APPEARANCEDLG_H
#define APPEARANCEDLG_H

#include <qvariant.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QGroupBox;
class QLabel;
class QComboBox;
class QPushButton;

class AppearanceDlg : public QDialog
{
    Q_OBJECT

public:
    AppearanceDlg( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~AppearanceDlg();

    QGroupBox* iconGroup;
    QLabel* sizeLabel;
    QComboBox* comboSize;
    QLabel* themeLabel;
    QComboBox* comboTheme;
    QPushButton* buttonOk;
    QPushButton* buttonCancel;
    QGroupBox* backGroup;
    QLabel* sitesLabel;
    QComboBox* comboSites;
    QLabel* ticksLabel;
    QComboBox* comboTicks;

protected:
    QGridLayout* AppearanceDlgLayout;
    QVBoxLayout* iconGroupLayout;
    QHBoxLayout* Layout1;
    QSpacerItem* Horizontal_Spacing2;
    QVBoxLayout* backGroupLayout;

protected slots:
    virtual void languageChange();

};

#endif // APPEARANCEDLG_H
