/***************************************************************************
 *   Copyright (C) 2005 by Tavarez Arnaud Bakoula                          *
 *   tbakoula@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef SITE_ROW_H
#define SITE_ROW_H

#include "cellrow.h"

class Site;

class SiteRow : public CellRow
{
public:
    SiteRow( uint idx, uint sz );
    virtual ~SiteRow();

    virtual void createCells();
    virtual void reset();
    virtual void ready();
    virtual void appendCells( uint ap );

private:
    SiteRow( const SiteRow& );
    SiteRow& operator=( const SiteRow& );
};

#endif // SITE_ROW_H
