/***************************************************************************
 *   Copyright (C) 2005 by Tavarez Arnaud Bakoula                          *
 *   tbakoula@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef MARK_H
#define MARK_H

#include "utilities.h"
/**
@author Tavarez Arnaud Bakoula
*/
class Mark
{
public:
    Mark( uint p=0, State c=MISPLACED ) : m_pos(p), m_state(c) {}
    /*!
     *  The copy constructor.
     */
    Mark( const Mark& p ) : m_pos( p.m_pos ), m_state( p.m_state ) {}
    /*!
     *  The destructor.
     */
    virtual ~Mark() {}

    void setPos( uint p )    {  m_pos   = p;  }
    void setState( State c ) {  m_state = c;  }
    void setState( uint c )
    {
      m_state = static_cast<State>( c );
    }
    uint  getPos() const      {  return m_pos;  }
    State getState() const  {  return m_state;  }

    bool operator==( Mark& mark ) const
    {
      return ( this->m_pos == mark.m_pos && this->m_state == mark.m_state );
    }
    bool operator!=( Mark& mark ) const
    {
      return !(*this == mark);
    }

protected:
    uint m_pos;       /*!< The position of the piece in the combination. */
    State m_state;    /*!< The state of the piece. */
};

#endif // MARK_H
