/***************************************************************************
 *   Copyright (C) 2005 by Tavarez Arnaud Bakoula                          *
 *   tbakoula@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "pion.h"

/*!
 *  \author T.A. Bakoula
 *
 *  \class Pion
 *  \brief The class Pion modelise a piece in a combination
 *
 *  It's compounded of a color and a index representing the
 *  position of the piece in the combination.
 */

/*!
 *  \fn Pion::Pion( uint p=0, Color c=None )
 *  \brief The constructor
 *
 *  It constructs an objet of the class whose position is
 *  \a pos and color \a c.
 */

/*!
 *  \fn void Pion::setColor( Color c )
 *  Sets the m_color member of the class to the value of c.
 */

/*!
 *  \fn void Pion::setColor( uint c )
 *  This function is provides for convenience and does the
 *  same thing than the function below.
 */

/*!
 *  \fn Color Pion::getColor() const
 *  This function returns the color of the piece.
 */

/*!
 *  \fn void Pion::setPos( uint pos )
 *  This function sets the m_pos member of the class to the
 *  value of pos.
 */

/*!
 *  \fn uint Pion::getPos() const
 *  This function returns the position of the piece.
 */

/*!
 *  \fn bool Pion::operator==(Pion& p) const
 *
 *  This function compares the object \a p to the current
 *  object and returns TRUE if the value of the respectives
 *  member of each object are the same.
 */

/*!
 *  \fn bool Pion::operator!=(Pion& p) const
 *
 *  This function compares the object \a p to the current
 *  object and returns TRUE if the value of the respectives
 *  member of each object are different.
 */


