/***************************************************************************
 *   Copyright (C) 2005 by Tavarez Arnaud Bakoula                          *
 *   tbakoula@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef TICK_H
#define TICK_H

#include "cell.h"

/**
   @author: T.A. Bakoula
 */
class Tick : public Cell
{
public:
    Tick( uint r, uint c, int st=2 )
      : Cell( r, c ), state( st ) {}
    virtual ~Tick() {}

    virtual void draw( QPainter*, QPoint pt=QPoint(0,0) );

    void setState( int st ) { state = st; }
    int  getState() const { return state; }

protected:
    int state;
};
#endif // TICK_H
