/***************************************************************************
 *   Copyright (C) 2005 by Tavarez Arnaud Bakoula                          *
 *   tbakoula@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef CELL_H
#define CELL_H

#include <qrect.h>

class QPainter;

/**
   @author: T.A. Bakoula
 */
class Cell
{
public:
    Cell( uint r, uint c ) :  row(r), col(c), m_empty(TRUE)
    {
       bound = QRect( 0, 0, size, size );
    }
    virtual ~Cell() {}

    virtual void draw( QPainter*, QPoint pt = QPoint(0,0) ) = 0;

    void setRow( uint r ) { row = r; }
    void setCol( uint c ) { col = c; }

    uint  getRow() const { return row; }
    uint  getCol() const { return col; }

    static void setSize( uint sz ) { size = sz; }
    static uint getSize() { return size; }

    QRect& rect() { return bound; }

    void empty( bool em )   { m_empty = em; }
    bool isEmpty() const  { return m_empty; }

protected:
    QRect bound;
    uint row;
    uint col;
    bool m_empty;
    static uint size;
};

#endif // CELL_H
